package jp.co.sds_corp.util.window;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.FocusAdapter;
import java.awt.event.FocusEvent;
import java.io.File;

import javax.swing.JButton;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

/**
* File を選択するPanelです。
* @author	小見山　聡
*/
public class FileSelector extends JPanel
{
	XYLayout xyLayout = new XYLayout( 450, 30 );
	JTextField EDT_FILE = new JTextField();
	JButton BTN_SEL = new JButton( "..." );
	JLabel LBL2 = new JLabel( "" );
	String	dir;
	JFileChooser chooser;
	/** ファイル種別 */
	public enum Type {
		/** ファイル種別：通常ファイル */
		ORD,
		/** ファイル種別：オーディオファイル */
		AUDIO,
		/** ファイル種別：画像ファイル */
		IMAGE;
	}

	String	selFile = null;

	/**
	* 指定されたディレクトリからファイルを選択するパネルを作成します。
	* @param	dir		ディレクトリ
	* @param	title	パネルに表示するタイトル
	*/
	public FileSelector( String dir, String title ) {
		this( dir, title, Type.ORD );
	}

	/**
	* 指定されたディレクトリからファイルを選択するパネルを作成します。
	* @param	dir		ディレクトリ
	* @param	title	パネルに表示するタイトル
	* @param	nType	ファイルの種別
	* @see		Type#ORD
	* @see		Type#AUDIO
	* @see		Type#IMAGE
	*/
	public FileSelector( String dir, String title, Type nType ) {
		super();
		this.dir = dir;
		setLayout(xyLayout);
		add( EDT_FILE, new XYConstraints( 50, 10, 200, 20 ));
		add( BTN_SEL, new XYConstraints( 255, 10, 20, 18 ));
		add( LBL2, new XYConstraints( 10, 10, 50, 18 ));
		JFileChooser fc = null;
		String path = new File( dir ).getAbsolutePath();
		switch ( nType ) {
		case ORD: fc = new JFileChooser( path ); break;
		case AUDIO: fc = new AudioChooser( path ); break;
		case IMAGE: fc = new ImageChooser( path ); break;
		}
		setChooser( fc );
		LBL2.setText( title + ":" );

		TextFocusHandler tf = new TextFocusHandler();
		EDT_FILE.addFocusListener( tf );

		BTN_SEL.addActionListener( new ActionListener() {
			public void actionPerformed( ActionEvent ev ) {
				File file = selectFile( ev );
				if ( file != null ) {
					selFile = file.getPath();
					EDT_FILE.setText( selFile );
				}
			}
		});
	}

	class TextFocusHandler extends FocusAdapter
	{
		public void focusGained( FocusEvent ev ) {
			JTextField txt = (JTextField ) ev.getSource();
			txt.selectAll();
		}
	}

	File selectFile( ActionEvent ev ) {
		chooser.setSelectedFile( new File( EDT_FILE.getText() ));
		int nRet = chooser.showOpenDialog( this );
		if ( nRet != JFileChooser.APPROVE_OPTION ) {
			return null;
		}
		return chooser.getSelectedFile();
	}

	public void setSelection( String file ) {
		selFile = file;
		EDT_FILE.setText( file );
	}

	public void setChooser( JFileChooser chooser ) {
		this.chooser = chooser;
	}

	public String getSelection() {
		return EDT_FILE.getText();
	}

	public void setEnabled( boolean en ) {
		LBL2.setEnabled( en );
		EDT_FILE.setEnabled( en );
		BTN_SEL.setEnabled( en );
		super.setEnabled( en );
	}
}

